<?php
/**
* Assessment controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessment.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckControllerAssessment extends JControllerForm
{
	/**
	* Saved id
	*/
	private $_id;

	/**
	* Method override to check if you can add a new record.
	*
	* @param array $data An array of input data.
	*
	* @return boolean
	*/
	protected function allowAdd($data = array())
	{
		// Initialise variables.
		$user = JFactory::getUser();

		$model = $this->getModel();
		$table = $model->getTable('check');
		if (isset($data['check_id'])) {
			$table->load($data['check_id']);

			if ($table->id) {
				// Existing Roughcheck check
				return $user->authorise(
					'assessment.create',
					$this->option . '.check.' . $table->id
				);
			} else {
				// New Roughcheck check
				return $user->authorise(
					'assessment.create',
					$this->option
				);
			}
		} else {
			// New Roughcheck check
			return $user->authorise(
				'assessment.create',
				$this->option
			);
		}
	}

	/**
	* Method to check if you can edit an existing record.
	*
	* @param array  $data An array of input data.
	* @param string $key  The name of the key for the primary key.
	*
	* @return  boolean
	*/
	protected function allowEdit($data = array(), $key = 'id')
	{
		// Initialise variables.
		$recordId = (int) isset($data[$key]) ? $data[$key] : 0;

		if ($recordId) {
			return JFactory::getUser()->authorise(
				'assessment.edit',
				$this->option . '.assessment.' . $recordId
			);
		}
	}

	/**
	* Function that allows this child controller access to model data
	* after the data has been saved.
	*
	* @param RoughcheckModelAssessment &$model    The data model object.
	* @param array                     $validData The validated data.
	*
	* @return  void
	*/
	protected function postSaveHook(JModelLegacy $model, $validData = array())
	{
		$this->_id = $model->getState($this->context . '.id');
	}

	/**
	* Method to save a record, then forward to the assessments.
	*
	* @param string $key    The name of the primary key of the URL variable.
	* @param string $urlVar The name of the URL variable if different from the
	*                       primary key (sometimes required to avoid router
	*                       collisions).
	*
	* @return	Boolean	True if successful, false otherwise.
	*/
	public function save($key = null, $urlVar = null)
	{
		$success = parent::save($key, $urlVar);

		$task = $this->getTask();

		if ($success && $task == 'save') {
			$route = 'index.php?option='.$this->option;
			$route .= '&task=assessments.assessmentquestions';
			$app = JFactory::getApplication();
			$tmpl   = $app->input->getCmd('tmpl');
			if ($tmpl) {
				$route .= '&tmpl=' . $tmpl;
			}
			if ($this->_id) {
				$route .= '&id=' . $this->_id;
			}
			$this->setRedirect(JRoute::_($route, false));
		}

		return $success;
	}
}
