<?php
/**
* Assessment questions controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessmentquestions.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment questions controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckControllerAssessmentquestions extends JControllerAdmin
{

	/**
	* Method to check if you can edit an existing record.
	*
	* @param array  $data An array of input data.
	* @param string $key  The name of the key for the primary key.
	*
	* @return  boolean
	*/
	protected function allowEdit($data = array(), $key = 'assessment_id')
	{
		// Initialise variables.
		$recordId = (int) isset($data[$key]) ? $data[$key] : 0;

		$model = $this->getModel('Assessmentquestions');
		$table = $model->getTable('Assessment');
		if ($recordId) {
			$table->load($recordId);
		}

		$user = JFactory::getUser();
		$userId = $user->get('id');
		$asset	= 'com_roughcheck.assessment.' . $recordId;
		$app = JFactory::getApplication();
		$userXref = $app->getUserState($asset);
		if ($user->authorise('assessment.edit', $asset)) {
			// User is allowed access
			JLog::add('Access via assessment.edit', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (
			!empty($userId)
			&& $user->authorise('assessment.edit.own', $asset)
			&& $userId == $table->created_by
		) {
			// User is allowed access to own assessment
			JLog::add('Access via assessment.edit.own', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (!empty($userXref) && $userXref == $table->xreference) {
			// User is allowed access via xreference
			JLog::add('Access via xref', JLog::DEBUG, COM_ROUGHCHECK);
		} else {
			// User is not allowed access to this assessment
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('No access to: ' . $asset, JLog::ERROR, COM_ROUGHCHECK);
			//throw new Exception(
			//	JText::_('JLIB_APPLICATION_ERROR_ACCESS_FORBIDDEN')
			//);
			$route = 'index.php?option='.$this->option;
			$route .= '&view=assessment';
			$route .= '&layout=xref';
			$tmpl   = $app->input->getCmd('tmpl');
			if ($tmpl) {
				$route .= '&tmpl=' . $tmpl;
			}
			$this->setRedirect(JRoute::_($route, false));
 			return false;
		}
		return true;
		$user = JFactory::getUser();
		if (!$user->authorise(
			'assessment.edit',
			$this->option . '.assessment.' . $assessment_id
		)) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'COM_ROUGHCHECK_ERROR_EDIT_ITEM_NOT_PERMITTED',
				JLog::NOTICE, COM_ROUGHCHECK
			);
			return false;
		}
	}

	/**
	* Method to save these questions, then move to the previous topic.
	*
	* @return int Number of questions successfully saved
	*/
	protected function saveResponses()
	{
		$model = $this->getModel('assessmentquestions');
		$success = $model->saveResponses();

		return $success;
	}

	/**
	* Method to save these questions, then move to the previous topic.
	*
	* @return void
	*/
	public function prev()
	{
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		$app = JFactory::getApplication();
		$assessment_id  = $app->input->getInt('assessment_id', 0);
		$topic_id  = $app->input->getInt('topic_id', 0);
		$message = '';

		$user = JFactory::getUser();
		if (!$user->authorise(
			'core.edit',
			$this->option . '.assessment.' . $assessment_id
		)) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'JLIB_APPLICATION_ERROR_EDIT_ITEM_NOT_PERMITTED',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$success = $this->saveResponses();
		if ($success) {
			$message = JText::sprintf('COM_ROUGHCHECK_RESPONSES_UPDATED', $success);
		}

		$model = $this->getModel('assessmentquestions');
		$model->setAssessment($assessment_id);
		$model->setTopic($topic_id);
		$prevtopic = $model->getPreviousTopic();

		$route = '';
		if ($prevtopic) {
			$route = 'index.php?option=' . $this->option
				. '&view=' . $this->view_list
				. '&id=' . $assessment_id
				. '&topic_id=' . $prevtopic;
		} else {
			$route = 'index.php?option=' . $this->option
				. '&view=assessments';
		}

		$this->setRedirect(JRoute::_($route, false), $message);

		return true;
	}

	/**
	* Method to save these questions, then move to the next topic.
	* or if check is completed, then move to the report.
	*
	* @return void
	*/
	public function next()
	{
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		$app = JFactory::getApplication();
		$assessment_id  = $app->input->getInt('assessment_id', 0);
		$topic_id  = $app->input->getInt('topic_id', 0);
		$message = '';

		$user = JFactory::getUser();
		if (!$user->authorise(
			'core.edit',
			$this->option . '.assessment.' . $assessment_id
		)) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'JLIB_APPLICATION_ERROR_EDIT_ITEM_NOT_PERMITTED',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$success = $this->saveResponses();
		if ($success) {
			$message = JText::sprintf('COM_ROUGHCHECK_RESPONSES_UPDATED', $success);
		}

		$model = $this->getModel('assessmentquestions');
		$model->setAssessment($assessment_id);
		$model->setTopic($topic_id);
		$nexttopic = $model->getNextTopic();

		$route = '';
		if ($nexttopic) {
			$route = 'index.php?option=' . $this->option
				. '&view=' . $this->view_list
				. '&id=' . $assessment_id
				. '&topic_id=' . $nexttopic;
		} else {
			$route = 'index.php?option=' . $this->option
				. '&view=assessmentreport'
				. '&id=' . $assessment_id;
		}

		$this->setRedirect(JRoute::_($route, false), $message);

		return true;
	}

	/**
	* Method to go to the report
	*
	* @return void
	*/
	public function assessmentreport()
	{
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		$app = JFactory::getApplication();
		$assessment_id  = $app->input->getInt('assessment_id', 0);

		$this->setRedirect(
			JRoute::_(
				'index.php?option=' . $this->option
				. '&view=assessmentreport'
				. '&id='.$assessment_id,
				false
			)
		);

		return true;
	}

	/**
	* Method to go to the assessment header
	*
	* @return void
	*/
	public function assessment()
	{
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		$app = JFactory::getApplication();
		$assessment_id  = $app->input->getInt('assessment_id', 0);

		$this->setRedirect(
			JRoute::_(
				'index.php?option=' . $this->option
				. '&task=assessment.edit'
				. '&id='.$assessment_id,
				false
			)
		);

		return true;
	}
}
