<?php
/**
* Assessment response controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessmentresponse.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment response controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckControllerAssessmentresponse extends JControllerForm
{
	/**
	* Method override to check if you can add a new record.
	*
	* @param array $data An array of input data.
	*
	* @return boolean
	*/
	protected function allowAdd($data = array())
	{
		// Set the assessment_id
		$app = JFactory::getApplication();
		$data['assessment_id'] = $app->input->getInt('a', 0);
		return $this->allowEdit($data);
	}

	/**
	* Method to check if you can add a new record.
	*
	* @param array  $data An array of input data.
	* @param string $key  The name of the key for the primary key.
	*
	* @return  boolean
	*/
	protected function allowEdit($data = array(), $key = 'assessment_id')
	{
		// Initialise variables.
		$recordId = (int) isset($data[$key]) ? $data[$key] : 0;

		$model = $this->getModel('Assessmentquestions');
		$table = $model->getTable('Assessment');
		if ($recordId) {
			$table->load($recordId);
		}

		$user = JFactory::getUser();
		$userId = $user->get('id');
		$asset	= 'com_roughcheck.assessment.' . $recordId;
		$app = JFactory::getApplication();
		$userXref = $app->getUserState($asset);
		if ($user->authorise('assessment.edit', $asset)) {
			// User is allowed access
			JLog::add('Access via assessment.edit', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (
			!empty($userId)
			&& $user->authorise('assessment.edit.own', $asset)
			&& $userId == $table->created_by
		) {
			// User is allowed access to own assessment
			JLog::add('Access via assessment.edit.own', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (!empty($userXref) && $userXref == $table->xreference) {
			// User is allowed access via xreference
			JLog::add('Access via xref', JLog::DEBUG, COM_ROUGHCHECK);
		} else {
			// User is not allowed access to this assessment
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('No access to: ' . $asset, JLog::ERROR, COM_ROUGHCHECK);
			$route = 'index.php?option='.$this->option;
			$route .= '&view=assessment';
			$route .= '&layout=xref';
			$tmpl   = $app->input->getCmd('tmpl');
			if ($tmpl) {
				$route .= '&tmpl=' . $tmpl;
			}
			$this->setRedirect(JRoute::_($route, false));
 			return false;
		}
		return true;
		$user = JFactory::getUser();
		if (!$user->authorise(
			'assessment.edit',
			$this->option . '.assessment.' . $assessment_id
		)) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'COM_ROUGHCHECK_ERROR_EDIT_ITEM_NOT_PERMITTED',
				JLog::NOTICE, COM_ROUGHCHECK
			);
			return false;
		}
	}

	/**
	* Method to save a record.
	*
	* @param string $key    The name of the primary key of the URL variable.
	* @param string $urlVar The name of the URL variable if different from the
	*                       primary key (sometimes required to avoid router
	*                       collisions).
	*
	* @return	Boolean	True if successful, false otherwise.
	*/
	public function save($key = null, $urlVar = null)
	{
		$success = parent::save($key, $urlVar);

		if ($success) {
			$this->setRedirect(
				'index.php?option=com_roughcheck&view=close&tmpl=component'
			);
		}

		return $success;
	}

	/**
	* Method to edit a record.
	*
	* @param string $key    The name of the primary key of the URL variable.
	* @param string $urlVar The name of the URL variable if different from the
	*                       primary key (sometimes required to avoid router
	*                       collisions).
	*
	* @return	Boolean	True if successful, false otherwise.
	*/
	public function edit($key = null, $urlVar = null)
	{
		$success = parent::edit($key, $urlVar);

		if (!$success) {
			$this->setRedirect(
				'index.php?option=com_roughcheck&view=close&tmpl=component'
			);
		}

		return $success;
	}

	/**
	* Method to cancel an edit.
	*
	* @param string $key The name of the primary key of the URL variable.
	*
	* @return boolean True if access level checks pass, false otherwise.
	*/
	public function cancel($key = null)
	{
		$success = parent::cancel($key);

		$this->setRedirect(
			'index.php?option=com_roughcheck&view=close&tmpl=component'
		);

		return $success;
	}

	/**
	* Method to add a new record.
	*
	* @return  mixed  True if the record can be added, a JError object if not.
	*/
	public function add()
	{
		// Initialise variables.
		$app = JFactory::getApplication();
		$input = $app->input;
		$context = "$this->option.edit.$this->context";
		$success = true;

		// Access check.
		if (!$this->allowAdd()) {
			// Set the internal error and also the redirect error.
			$this->setError(
				JText::_('JLIB_APPLICATION_ERROR_CREATE_RECORD_NOT_PERMITTED')
			);
			$this->setMessage($this->getError(), 'error');

			$success = false;
		}

		if ($success) {
			// Clear the record edit information from the session.
			$app->setUserState($context . '.data', null);
		}

		if ($success) {
			$route = 'index.php?option=' . $this->option;
 			$route .= '&view=' . $this->view_item;
 			$route .= '&tmpl=' . $input->getCmd('tmpl', '');
 			$route .= '&layout=' . $input->getCmd('layout', '');
 			$route .= '&a=' . $input->getCmd('a', '');
 			$route .= '&q=' . $input->getCmd('q', '');
			$this->setRedirect($route, false);
		} else {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Create record not permitted', JLog::ERROR, COM_ROUGHCHECK);
			$this->setRedirect(
				'index.php?option=com_roughcheck&view=close&tmpl=component'
			);
		}

		return $success;
	}

}
