<?php
/**
* Check topic controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checktopic.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Check topic controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckControllerChecktopic extends JControllerForm
{
	/**
	* Method override to check if you can add a new record.
	*
	* @param array $data An array of input data.
	*
	* @return boolean
	*/
	protected function allowAdd($data = array())
	{
		$app = JFactory::getApplication();
		$context = "$this->option.edit.$this->context";
		$checkId = $app->getUserState("$context.check_id", 0);
		$ret = false;

		if ($checkId) {
			$ret = JFactory::getUser()->authorise(
				'core.create', $this->option . '.check.' . $checkId
			);
		}
		return $ret;
	}

	/**
	* Method to check if you can edit an existing record.
	*
	* @param array  $data An array of input data.
	* @param string $key  The name of the key for the primary key.
	*
	* @return  boolean
	*/
	protected function allowEdit($data = array(), $key = 'id')
	{
		// Initialise variables.
		$recordId = (int) isset($data[$key]) ? $data[$key] : 0;
		$checkId = 0;

		if ($recordId) {
			$checkId = (int) $this->getModel()->getItem($recordId)->check_id;
		} else {
			$app = JFactory::getApplication();
			$context = "$this->option.edit.$this->context";
			$checkId = $app->getUserState("$context.check_id", 0);
		}

		if ($checkId) {
			return JFactory::getUser()->authorise(
				'core.edit', $this->option . '.check.' . $checkId
			);
		} else {
			return false;
		}
	}

	/**
	* Method to cancel an edit.
	*
	* @param string $key The name of the primary key of the URL variable.
	*
	* @return	Boolean	True if access level checks pass, false otherwise.
	*/
	public function cancel($key = null)
	{
		$success = parent::cancel($key);

		if ($success) {
			$app = JFactory::getApplication();
			$data = $this->input->post->get('jform', array(), 'array');
			$id = $data['check_id'];
			$route = 'index.php?option='.$this->option;
			$route .= '&view='.$this->view_list;
			$tmpl   = $app->input->getCmd('tmpl');
			if ($tmpl) {
				$route .= '&tmpl=' . $tmpl;
			}
			if ($id) {
				$route .= '&id=' . $id;
			}
			$this->setRedirect(JRoute::_($route, false));
		}

		return $success;
	}

	/**
	* Method to save a record.
	*
	* @param string $key    The name of the primary key of the URL variable.
	* @param string $urlVar The name of the URL variable if different from the
	*                       primary key (sometimes required to avoid router
	*                       collisions).
	*
	* @return boolean True if successful, false otherwise.
	*/
	public function save($key = null, $urlVar = null)
	{
		$success = parent::save($key, $urlVar);

		$task = $this->getTask();

		if ($success && $task == 'save') {
			$app = JFactory::getApplication();
			$data = $this->input->post->get('jform', array(), 'array');
			$id = $data['check_id'];
			$route = 'index.php?option='.$this->option;
			$route .= '&view='.$this->view_list;
			$tmpl   = $app->input->getCmd('tmpl');
			if ($tmpl) {
				$route .= '&tmpl=' . $tmpl;
			}
			if ($id) {
				$route .= '&id=' . $id;
			}
			$this->setRedirect(JRoute::_($route, false));
		}

		return $success;
	}

	/**
	* Method to add a new record.
	*
	* @return  mixed  True if the record can be added, a JError object if not.
	*/
	public function add()
	{
		$app = JFactory::getApplication();
		$check_id = $app->input->getInt('check_id', 0);
		$context = "$this->option.edit.$this->context";
		$app->setUserState($context.'.check_id', $check_id);

		$success = parent::add();

		return $success;
	}
}
