<?php
/**
* Rouchcheck helper
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: roughcheck.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Roughcheck helper
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckHelper
{

	/**
	* Configure the Linkbar.
	*
	* @param string $submenu Sub menu to add
	*
	* @return void
	*/
	public static function addSubmenu($submenu) 
	{
		JHtmlSidebar::addEntry(
			JText::_('COM_ROUGHCHECK_MENU_ROUGHCHECK'),
			'index.php?option=com_roughcheck&view=roughcheck',
			$submenu == 'roughcheck'
		);
		JHtmlSidebar::addEntry(
			JText::_('COM_ROUGHCHECK_MENU_CHECKS'),
			'index.php?option=com_roughcheck&view=checks',
			$submenu == 'checks'
		);
		JHtmlSidebar::addEntry(
			JText::_('COM_ROUGHCHECK_MENU_ASSESSMENTS'),
			'index.php?option=com_roughcheck&view=assessments',
			$submenu == 'assessments'
		);
		JHtmlSidebar::addEntry(
			JText::_('JCATEGORIES'),
			'index.php?option=com_categories&amp;extension=com_roughcheck',
			$submenu == 'categories'
		);
		JHtmlSidebar::addEntry(
			JText::_('COM_ROUGHCHECK_MENU_RISKS'),
			'index.php?option=com_roughcheck&view=risks',
			$submenu == 'risks'
		);
		JHtmlSidebar::addEntry(
			JText::_('COM_ROUGHCHECK_MENU_REWARDS'),
			'index.php?option=com_roughcheck&view=rewards',
			$submenu == 'rewards'
		);
		JHtmlSidebar::addEntry(
			JText::_('COM_ROUGHCHECK_MENU_HELPS'),
			'index.php?option=com_roughcheck&view=helps',
			$submenu == 'helps'
		);
	}

	/**
	 * Gets a list of the actions that can be performed.
	 *
	 * @param int $categoryId The category ID.
	 * @param int $checkId    The check ID.
	 *
	 * @return	JObject Actions object
	 */
	public static function getActions($categoryId = 0, $checkId = 0)
	{
		$user	= JFactory::getUser();
		$result	= new JObject;

		if (empty($checkId) && empty($categoryId)) {
			$assetName = COM_ROUGHCHECK;
		} elseif (empty($checkId)) {
			$assetName = COM_ROUGHCHECK . '.category.' . (int) $categoryId;
		} else {
			$assetName = COM_ROUGHCHECK . '.check.' . (int) $checkId;
		}

		$actions = array(
			'core.admin', 'core.manage', 'core.create',
			'core.edit', 'core.edit.own', 'core.edit.state', 'core.delete',
			'assessment.create', 'assessment.delete', 'assessment.edit',
			'assessment.edit.own', 'assessment.edit.state', 'assessment.edit.xref',
			'assessment.manage'
		);

		foreach ($actions as $action) {
			$result->set($action, $user->authorise($action, $assetName));
		}

		return $result;
	}

	/**
	* generate Unique Universal IDentifier
	*
	* @return string a new UUID
	*/
	public static function uuid()
	{
		// use uuid extension from PECL if available
		if (function_exists("uuid_create")) {
			return uuid_create();
		}

		// fallback
		// this should be random enough for now
		$uuid = md5(microtime().getmypid());

		// set variant and version fields for 'true' random uuid
		$uuid{12} = "4";
		$n = 8 + (ord($uuid{16}) & 3);
		$hex = "0123456789abcdef";
		$uuid{16} = $hex{$n};

		// return formated uuid
		return substr($uuid,  0, 8)."-"
			.  substr($uuid,  8, 4)."-"
			.  substr($uuid, 12, 4)."-"
			.  substr($uuid, 16, 4)."-"
			.  substr($uuid, 20);
	}

	/**
	* Applies the content tag filters to arbitrary text as per settings
	* for current user group
	*
	* @param text The string to filter
	*
	* @return string The filtered string
	*/
//@codingStandardsIgnoreStart
	public static function filterText($text)
	{
		// Filter settings
		$config		= JComponentHelper::getParams('com_config');
		$user		= JFactory::getUser();
		$userGroups	= JAccess::getGroupsByUser($user->get('id'));

		$filters = $config->get('filters');

		$blackListTags			= array();
		$blackListAttributes	= array();

		$customListTags			= array();
		$customListAttributes	= array();

		$whiteListTags			= array();
		$whiteListAttributes	= array();

		$noHtml				= false;
		$whiteList			= false;
		$blackList			= false;
		$customList			= false;
		$unfiltered			= false;

		// Cycle through each of the user groups the user is in.
		// Remember they are included in the Public group as well.
		foreach ($userGroups as $groupId)
		{
			// May have added a group but not saved the filters.
			if (!isset($filters->$groupId)) {
				continue;
			}

			// Each group the user is in could have different filtering properties.
			$filterData = $filters->$groupId;
			$filterType	= strtoupper($filterData->filter_type);

			if ($filterType == 'NH') {
				// Maximum HTML filtering.
				$noHtml = true;
			}
			elseif ($filterType == 'NONE') {
				// No HTML filtering.
				$unfiltered = true;
			}
			else {
				// Black, white or custom list.
				// Preprocess the tags and attributes.
				$tags			= explode(',', $filterData->filter_tags);
				$attributes		= explode(',', $filterData->filter_attributes);
				$tempTags		= array();
				$tempAttributes	= array();

				foreach ($tags as $tag)
				{
					$tag = trim($tag);

					if ($tag) {
						$tempTags[] = $tag;
					}
				}

				foreach ($attributes as $attribute)
				{
					$attribute = trim($attribute);

					if ($attribute) {
						$tempAttributes[] = $attribute;
					}
				}

				// Collect the black or white list tags and attributes.
				// Each lists is cummulative.
				if ($filterType == 'BL') {
					$blackList				= true;
					$blackListTags			= array_merge($blackListTags, $tempTags);
					$blackListAttributes	= array_merge($blackListAttributes, $tempAttributes);
				}
				elseif ($filterType == 'CBL') {
					// Only set to true if Tags or Attributes were added
					if ($tempTags || $tempAttributes) {
						$customList				= true;
						$customListTags			= array_merge($customListTags, $tempTags);
						$customListAttributes	= array_merge($customListAttributes, $tempAttributes);
					}
				}
				elseif ($filterType == 'WL') {
					$whiteList				= true;
					$whiteListTags			= array_merge($whiteListTags, $tempTags);
					$whiteListAttributes	= array_merge($whiteListAttributes, $tempAttributes);
				}
			}
		}

		// Remove duplicates before processing (because the black list uses both sets of arrays).
		$blackListTags			= array_unique($blackListTags);
		$blackListAttributes	= array_unique($blackListAttributes);
		$customListTags			= array_unique($customListTags);
		$customListAttributes	= array_unique($customListAttributes);
		$whiteListTags			= array_unique($whiteListTags);
		$whiteListAttributes	= array_unique($whiteListAttributes);

		// Unfiltered assumes first priority.
		if ($unfiltered) {
			// Dont apply filtering.
		}
		else {
			// Custom blacklist precedes Default blacklist
			if ($customList) {
				$filter = JFilterInput::getInstance(array(), array(), 1, 1);

				// Override filter's default blacklist tags and attributes
				if ($customListTags) {
					$filter->tagBlacklist = $customListTags;
				}
				if ($customListAttributes) {
					$filter->attrBlacklist = $customListAttributes;
				}
			}
			// Black lists take third precedence.
			elseif ($blackList) {
				// Remove the white-listed attributes from the black-list.
				$filter = JFilterInput::getInstance(
					array_diff($blackListTags, $whiteListTags), 			// blacklisted tags
					array_diff($blackListAttributes, $whiteListAttributes), // blacklisted attributes
					1,														// blacklist tags
					1														// blacklist attributes
				);
				// Remove white listed tags from filter's default blacklist
				if ($whiteListTags) {
					$filter->tagBlacklist = array_diff($filter->tagBlacklist, $whiteListTags);
				}
				// Remove white listed attributes from filter's default blacklist
				if ($whiteListAttributes) {
					$filter->attrBlacklist = array_diff($filter->attrBlacklist);
				}

			}
			// White lists take fourth precedence.
			elseif ($whiteList) {
				$filter	= JFilterInput::getInstance($whiteListTags, $whiteListAttributes, 0, 0, 0);  // turn off xss auto clean
			}
			// No HTML takes last place.
			else {
				$filter = JFilterInput::getInstance();
			}

			$text = $filter->clean($text, 'html');
		}

		return $text;
	}
//@codingStandardsIgnoreEnd

	/**
	* Show the feature/unfeature links
	*
	* @param int     $value      The state value
	* @param int     $i          Row number
	* @param boolean $canChange  Is user allowed to change?
	*
	* @return string HTML code
	*/
	public static function featured($value = 0, $i = 0, $canChange = true)
	{
		JHtml::_('bootstrap.tooltip');

		// Array of image, task, title, action
		$states	= array(
			0	=> array('unfeatured',	'checks.featured',	'COM_ROUGHCHECK_UNFEATURED',	'COM_ROUGHCHECK_TOGGLE_TO_FEATURE'),
			1	=> array('featured',	'checks.featured',	'COM_ROUGHCHECK_FEATURED',		'COM_ROUGHCHECK_TOGGLE_TO_UNFEATURE'),
		);
		$state	= JArrayHelper::getValue($states, (int) $value, $states[1]);
		$icon	= $state[0];

		if ($canChange)
		{
			$html	= '<a href="#" onclick="return listItemTask(\'cb' . $i . '\',\'' . $state[1] . '\')" class="btn btn-micro hasTooltip' . ($value == 1 ? ' active' : '') . '" title="' . JHtml::tooltipText($state[3]) . '"><i class="icon-'
					. $icon . '"></i></a>';
		}
		else
		{
			$html	= '<a class="btn btn-micro hasTooltip disabled' . ($value == 1 ? ' active' : '') . '" title="' . JHtml::tooltipText($state[2]) . '"><i class="icon-'
					. $icon . '"></i></a>';
		}

		return $html;
	}

	/**
	* Build html form output
	*
	* @param array $fieldset Form fieldset to render
	*
	* @return string HTML code
	*/
	public static function htmlFormOutput($fieldset)
	{
		$html = '';
		$tabs = '					';
		foreach ($fieldset as $field) {
			$html .= $tabs.'<div class="control-group">'."\n";
			$html .= $tabs.'	<div class="control-label">'."\n";
			$html .= $tabs.'		'. $field->label."\n";
			$html .= $tabs.'	</div>'."\n";
			$html .= $tabs.'	<div class="controls">'."\n";
			$html .= $tabs.'		' . $field->input."\n";
			$html .= $tabs.'	</div>'."\n";
			$html .= $tabs.'</div>'."\n";
		}

		return $html;
	}

}
