<?php
/**
* Assessment model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessment.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelAssessment extends JModelAdmin
{

	/**
	* Method to test whether a record can be deleted.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to delete the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canDelete($record)
	{
		if (!empty($record->id)) {
			if ($record->state != -2) {
				return ;
			}
			$user = JFactory::getUser();
			$asset = 'com_roughcheck.assessment.'.(int) $record->id;
			return $user->authorise('assessment.delete', $asset);
		}
	}

	/**
	* Method to test whether a record can have its state changed.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to change the state of the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canEditState($record)
	{
		$user = JFactory::getUser();

		if (!empty($record->id)) {
			$user = JFactory::getUser();
			$asset = 'com_roughcheck.assessment.'.(int) $record->id;
			return $user->authorise('assessment.edit.state', $asset);
		} else {
			return parent::canEditState($record);
		}
	}

	/**
	* Method to get the form record.
	*
	* @param array   $data     Data for the form.
	* @param boolean $loadData True if the form is to load its own data
	*                          (default case), false if not.
	*
	* @return mixed A JForm object on success, false on failure
	*/
	public function getForm($data = array(), $loadData = true) 
	{
		// Get the form.
		$form = $this->loadForm(
			'com_roughcheck.assessment', 'assessment',
			array('control' => 'jform', 'load_data' => $loadData)
		);
		if (empty($form)) {
			return false;
		}

		// Determine correct permissions to assessment.
		if ($this->getState('assessment.id')) {
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('catid', 'action', 'assessment.edit');
		} else {
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('catid', 'action', 'assessment.create');
		}

		// Modify the form based on access controls.
		if (!$this->canEditState((object) $data)) {
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');
			$form->setFieldAttribute('publish_up', 'disabled', 'true');
			$form->setFieldAttribute('publish_down', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
			$form->setFieldAttribute('publish_up', 'filter', 'unset');
			$form->setFieldAttribute('publish_down', 'filter', 'unset');
		}

		// If this is a new record for display, no need to present various fields
		if (isset($data['id']) && $data['id']) {
			$form->setFieldAttribute('check_id', 'readonly', 'true');
			$form->setFieldAttribute('check_id', 'readonly', 'true');
		} else {
			$form->removeField('xreference');
		}
		return $form;
	}

	/**
	* Method to get the data that should be injected in the form.
	*
	* @return mixed The data for the form.
	*/
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState(
			'com_roughcheck.edit.assessment.data', array()
		);
		if (empty($data)) {
			$data = $this->getItem();
		}

		// Prime some default values.
		if ($this->getState('assessment.id') == 0) {
			$app = JFactory::getApplication();

			$cat_default = $app->getUserState('com_roughcheck.checks.filter.category_id');
			$data->set('catid',$app->input->getInt('catid', $cat_default));
		}

		return $data;
	}

}
