<?php
/**
* Assessment questions model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessmentquestions.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment questions model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelAssessmentquestions extends JModelList
{

	private $_assessment;
	private $_topic;

	/**
	* Constructor
	*
	* @param array $config An optional associative array of configuration settings.
	*
	* @see   JController
	*/
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'state',
				'id', 'a.id',
				'title', 'a.title',
				'description', 'a.description',
				'checked_out', 'a.checked_out',
				'checked_out_time', 'a.checked_out_time',
				'catid', 'ck.catid', 'category_title',
				'state', 'a.state',
				'access', 'ck.access', 'access_level',
				'created', 'a.created',
				'created_by', 'a.created_by',
				'language', 'ck.language',
				);
		}

		parent::__construct($config);
	}

	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param string $ordering  An optional ordering field.
	 * @param string $direction An optional direction (asc|desc).
	 *
	 * @return  void
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $this->getUserStateFromRequest(
			$this->context.'.filter.search', 'filter_search'
		);
		$this->setState('filter.search', $search);

		$accessId = $this->getUserStateFromRequest(
			$this->context.'.filter.access', 'filter_access', null, 'int'
		);
		$this->setState('filter.access', $accessId);

		$categoryId = $this->getUserStateFromRequest(
			$this->context.'.filter.category_id', 'filter_category_id', ''
		);
		$this->setState('filter.category_id', $categoryId);

		$language = $this->getUserStateFromRequest(
			$this->context.'.filter.language', 'filter_language', ''
		);
		$this->setState('filter.language', $language);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_roughcheck');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('q.ordering', 'asc');
	}

	/**
	* Returns list query
	*
	* @return string sql list query
	*/
	protected function getListQuery()
	{
		$assessment = $this->getAssessment();
		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unable to get assessment', JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}

		$topic = $this->getTopic();
		if (!$topic) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unable to get topic', JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id');
		$query->select('a.title');
		$query->select('a.check_id');
		$query->select('a.topic_id');
		$query->select('a.ordering');
		$query->select('a.state');
		$query->select('a.risk_detail_id AS question_risk_detail_id');
		$query->select('a.risk_trigger');
		$query->select('a.reward_detail_id AS question_reward_detail_id');
		$query->select('a.reward_trigger');
		$query->select('b.id as assessment_id');
		$query->select('c.risk_detail_id AS response_risk_detail_id');
		$query->select('c.reward_detail_id AS response_reward_detail_id');
		if ($db->name == 'postgresql') {
			$query->select('c.response');
		} else {
			$case = 'CASE c.response '
					. 'WHEN 0 THEN "f" '
					. 'WHEN 1 THEN "t" '
					. 'ELSE NULL '
					. 'END AS response';
			$query->select($case);
		}
		$query->select('c.id as response_id');
		$query->select('a.modified, a.modified_by');
		$query->select('a.created, a.created_by');
		$query->select('a.checked_out, a.checked_out_time');
		$query->from('#__roughcheck_check_questions AS a');
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS b '
			. 'ON a.check_id = b.check_id '
			. 'AND b.id = ' . $db->escape($assessment->id)
		);
		$query->join(
			'LEFT',
			'#__roughcheck_assessment_responses AS c '
			. 'ON a.id = c.question_id '
			. 'AND b.id = c.assessment_id'
		);

		$query->where('a.state = 1');
		$query->where('a.topic_id = ' . $db->escape((int)$topic->id));

		$query->order('a.ordering');

		return $query;
	}

	/**
	* Method to set an assessment
	*
	* @param int $assessment_id ID of the Assessment to load
	*
	* @return JTable Table object of the assessment
	*/
	public function setAssessment($assessment_id)
	{
		$table = $this->getTable('assessment');
		$table->load($assessment_id);
		if (!$table->id) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unknown assessment: '.$id, JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}
		$this->_assessment = $table;
	}

	/**
	* Method to get an array of data items.
	*
	* @return JTable Table object of the assessment or false on failure.
	*/
	public function getAssessment()
	{
		if ($this->_assessment) {
			return $this->_assessment;
		}

		$app = JFactory::getApplication();
		$id = $app->input->getInt('assessment_id', 0);
		if (! $id) {
			$id = $app->input->getInt('id', 0);
		}
		$table = $this->getTable('assessment');
		try {
			$table->load($id);
		}
		catch (Exception $e)
		{
			JLog::add(
				'Unable to getAssessment: '.$e->getMessage(),
				JLog::DEBUG, COM_ROUGHCHECK
			);
			$this->setError($e->getMessage());
			return array();
		}
		if (!$table->id) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unknown assessment: '.$id, JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}
		$this->_assessment = $table;

		return $this->_assessment;
	}

	/**
	* Method to set an assessment topic
	*
	* @param int $topic_ordering Faux ID of the Topic to load
	*
	* @return JTable Table object of the topic
	*/
	public function setTopic($topic_ordering)
	{
		if (!$this->_assessment) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add(
				'Must set assessment before topic: '.$topic_ordering,
				JLog::ERROR,
				COM_ROUGHCHECK
			);
			return false;
		}
		$filter = array();
		$filter['check_id'] = $this->_assessment->check_id;
		$filter['ordering'] = $topic_ordering;
		$filter['state'] = 1;

		$table = $this->getTable('checktopic');
		$table->load($filter);
		if (!$table->id) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unknown topic: '.$topic_ordering, JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}
		$this->_topic = $table;
	}

	/**
	* Method to get the current topic
	*
	* @return JTable Table object of the topic
	*/
	public function getTopic()
	{
		if ($this->_topic) {
			return $this->_topic;
		}

		if (!$this->_assessment) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add(
				'Must set assessment before getting topic',
				JLog::ERROR, COM_ROUGHCHECK
			);
			return false;
		}

		$app = JFactory::getApplication();
		$topic_ordering = $app->input->getInt('topic_id', 0);

		if (!$topic_ordering) {
			$db = $this->getDBO();
			$query = $db->getQuery(true);
			$query->select('MIN(ordering)');
			$query->from('#__roughcheck_check_topics');
			$query->where('check_id = ' . $db->escape($this->_assessment->check_id));
			$query->where('state = 1');
			$db->setQuery($query);
			$topic_ordering = $db->loadResult($query);
		}

		$filter = array();
		$filter['check_id'] = $this->_assessment->check_id;
		$filter['ordering'] = $topic_ordering;
		$filter['state'] = 1;

		$table = $this->getTable('checktopic');
		$table->load($filter);
		$this->_topic = $table;

		return $this->_topic;
	}

	/**
	* Method to get the Next Topic id.
	*
	* @return int Next topic Faux id or zero
	*/
	public function getNextTopic()
	{
		$topic = $this->getTopic();

		if (!$topic) {
			return 0;
		}

		if ($topic->id == 0) {
			return 0;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('MIN(ordering)');
		$query->from('#__roughcheck_check_topics');
		$query->where('check_id = ' . $db->escape($topic->check_id));
		$query->where('ordering > ' . $db->escape($topic->ordering));
		$query->where('state = 1');
		$db->setQuery($query);
		$next_ordering = $db->loadResult($query);

		if (!$next_ordering) {
			return 0;
		}
		return $next_ordering;
	}

	/**
	* Method to get the Previous Topic id.
	*
	* @return int Previous Faux id or zero
	*/
	public function getPreviousTopic()
	{
		$topic = $this->getTopic();

		if (!$topic) {
			return 0;
		}

		if ($topic->id == 0) {
			return 0;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('MAX(ordering)');
		$query->from('#__roughcheck_check_topics');
		$query->where('check_id = ' . $db->escape($topic->check_id));
		$query->where('ordering < ' . $db->escape($topic->ordering));
		$query->where('state = 1');
		$db->setQuery($query);
		$prev_ordering = $db->loadResult($query);

		if (!$prev_ordering) {
			return 0;
		}
		return $prev_ordering;
	}

	/**
	* Method to get the risk profile available for this check.
	*
	* @return array of risk objects
	*/
	public function getRiskprofile()
	{
		$assessment = $this->getAssessment();

		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'No assessment to find available risk profile!',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id, a.title, a.report_title');
		$query->select('a.unknown, a.positive, a.negative');
		$query->select('a.unknownimage, a.positiveimage, a.negativeimage');
		$query->from('#__roughcheck_risk_profiles as a');
		$query->join(
			'INNER',
			'#__roughcheck_checks AS c '
			. 'ON a.id = c.risk_profile_id'
		);
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS d '
			. 'ON d.check_id = c.id '
		);
		$query->where('d.id = ' . $db->escape($assessment->id));
		$query->where('c.state = 1');
		$query->where('a.state = 1');

		$db->setQuery($query);

		$result = $db->loadObject();

		return $result;
	}

	/**
	* Method to get the risk details available for this check.
	*
	* @return array of risk objects
	*/
	public function getRisks()
	{
		$assessment = $this->getAssessment();

		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'No assessment to find available risks!',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id,a.title');
		$query->from('#__roughcheck_risk_details as a');
		$query->join(
			'INNER',
			'#__roughcheck_checks AS c '
			. 'ON a.risk_profile_id = c.risk_profile_id'
		);
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS d '
			. 'ON d.check_id = c.id '
		);
		$query->where('d.id = ' . $db->escape($assessment->id));
		$query->where('a.state = 1');
		$query->order('a.ordering');

		$db->setQuery($query);

		$result = $db->loadObjectList();

		return $result;
	}

	/**
	* Method to get the reward profile available for this check.
	*
	* @return array of risk objects
	*/
	public function getRewardprofile()
	{
		$assessment = $this->getAssessment();

		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'No assessment to find available reward profile!',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id, a.title, a.report_title');
		$query->select('a.unknown, a.positive, a.negative');
		$query->select('a.unknownimage, a.positiveimage, a.negativeimage');
		$query->from('#__roughcheck_reward_profiles as a');
		$query->join(
			'INNER',
			'#__roughcheck_checks AS c '
			. 'ON a.id = c.reward_profile_id'
		);
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS d '
			. 'ON d.check_id = c.id '
		);
		$query->where('d.id = ' . $db->escape($assessment->id));
		$query->where('c.state = 1');
		$query->where('a.state = 1');

		$db->setQuery($query);

		$result = $db->loadObject();

		return $result;
	}

	/**
	* Method to get the reward details available for this check.
	*
	* @return array of reward objects
	*/
	public function getRewards()
	{
		$assessment = $this->getAssessment();

		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'No assessment to find available rewards!',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id,a.title');
		$query->from('#__roughcheck_reward_details as a');
		$query->join(
			'INNER',
			'#__roughcheck_checks AS c '
			. 'ON a.reward_profile_id = c.reward_profile_id'
		);
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS d '
			. 'ON d.check_id = c.id '
		);
		$query->where('d.id = ' . $db->escape($assessment->id));
		$query->where('a.state = 1');
		$query->order('a.ordering');

		$db->setQuery($query);

		$result = $db->loadObjectList();

		return $result;
	}

	/**
	* Function to return the list of questions to response
	*
	* @return array list of questions
	*/
	public function getQuestions()
	{

		$db = $this->getDBO();
		$db->setQuery($this->getListQuery());
		$results = $db->loadObjectList();

		return $results;
	}

	/**
	* Method to save these questions for a topic.
	*
	* @return int Number of questions successfully saved
	*/
	public function saveResponses()
	{
		$success = 0;
		$app = JFactory::getApplication();
		$assessment_id  = $app->input->getInt('assessment_id', 0);
		$topic_id  = $app->input->getInt('topic_id', 0);
		$this->setAssessment($assessment_id);
		$this->setTopic($topic_id);
		$questions = $this->getQuestions();

		foreach ($questions as $i => $question) {
			$table = $this->getTable('assessmentresponse');
			$keys = array();
			$keys['assessment_id'] = $question->assessment_id;
			$keys['question_id'] = $question->id;
			try {
				$table->load($keys);
			}
			catch (Exception $e){
				// Ignore record if it does not exist
				JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
				JLog::add(
					'Exception: '.$e->getMessage(),
					JLog::ERROR, COM_ROUGHCHECK
				);
			}

			$options = array();
			$data  = $app->input->post->get('jform' . $question->id, array(), 'array');

			if (array_key_exists('response', $data)
				&& ($data['response'] == '0' || $data['response'] == '1')
			) {
				$data['question_id'] = $question->id;
				$data['assessment_id'] = $question->assessment_id;
				try {
					$table->save($data);
					$success += 1;
				}
				catch (Exception $e){
					// Ignore record if it does not exist
					JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
					JLog::add(
						'Exception: '.$e->getMessage(),
						JLog::ERROR, COM_ROUGHCHECK
					);
				}
			}
		}
		return $success;
	}

}
