<?php
/**
* Questions model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checkquestions.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Questions model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelCheckquestions extends JModelList
{

	// Check object
	protected $_check;

	/**
	* Constructor
	*
	* @param array $config An optional associative array of configuration settings.
	*
	* @see   JController
	*/
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'state',
				'id', 'a.id',
				'title', 'a.title',
				'topic_id', 'a.topic_id',
				'topic_title', 'a.topic_title',
				'risk_title',
				'risk_trigger',
				'description', 'a.description',
				'checked_out', 'a.checked_out',
				'checked_out_time', 'a.checked_out_time',
				'state', 'a.state',
				'ordering',
				'created', 'a.created',
				'created_by', 'a.created_by',
				);
		}

		parent::__construct($config);
	}

	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param string $ordering  An optional ordering field.
	 * @param string $direction An optional direction (asc|desc).
	 *
	 * @return  void
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $this->getUserStateFromRequest(
			$this->context.'.filter.search', 'filter_search'
		);
		$this->setState('filter.search', $search);

		$accessId = $this->getUserStateFromRequest(
			$this->context.'.filter.access', 'filter_access', null, 'int'
		);
		$this->setState('filter.access', $accessId);

		$published = $this->getUserStateFromRequest(
			$this->context.'.filter.state', 'filter_published', '', 'string'
		);
		$this->setState('filter.state', $published);

		$categoryId = $this->getUserStateFromRequest(
			$this->context.'.filter.category_id', 'filter_category_id', ''
		);
		$this->setState('filter.category_id', $categoryId);

		$topicId = $this->getUserStateFromRequest(
			$this->context.'.filter.topic', 'filter_topic', '', 'string'
		);
		$this->setState('filter.topic_id', $topicId);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_roughcheck');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('ordering', 'asc');
	}

	/**
	* Returns list query
	*
	* @return string sql list query
	*/
	protected function getListQuery()
	{
		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id,a.ordering');
		$query->select('a.title');
		$query->select('a.check_id');
		$query->select('a.topic_id');
		$query->select('a.risk_detail_id');
		$query->select('a.risk_trigger');
		$query->select('a.reward_detail_id');
		$query->select('a.reward_trigger');
		$query->select('a.state');
		$query->select('a.publish_up, a.publish_down');
		$query->select('a.created, a.created_by');
		$query->select('a.checked_out, a.checked_out_time');
		$query->select('a.modified, a.modified');
		$query->from($db->quoteName('#__roughcheck_check_questions').' AS a');

		$query->select('rd.title AS risk_title');
		$query->join(
			'INNER',
			$db->quoteName('#__roughcheck_risk_details')
			. ' AS rd ON rd.id=a.risk_detail_id'
		);
		$query->join(
			'INNER',
			$db->quoteName('#__roughcheck_risk_profiles')
			. ' AS rp ON rp.id=rd.risk_profile_id'
		);
		$query->select('rwd.title AS reward_title');
		$query->join(
			'INNER',
			$db->quoteName('#__roughcheck_reward_details')
			. ' AS rwd ON rwd.id=a.reward_detail_id'
		);
		$query->join(
			'INNER',
			$db->quoteName('#__roughcheck_reward_profiles')
			. ' AS rwp ON rwp.id=rwd.reward_profile_id'
		);

		$query->select('t.title AS topic_title');
		$query->join(
			'INNER',
			$db->quoteName('#__roughcheck_check_topics')
			. ' AS t ON t.id=a.topic_id'
		);

		// Join over the users for the checked out user.
		$query->select('uc.name AS editor');
		$query->join(
			'LEFT',
			$db->quoteName('#__users') . ' AS uc ON uc.id=a.checked_out'
		);

		// Filter by check_id
		$app = JFactory::getApplication();
		$check_id = $app->input->getInt('id', 0);
		if ($check_id) {
			$query->where('a.check_id = '. $check_id);
		}

		// Filter by topic
		$topic_id = (int) $this->getState('filter.topic_id');
		if ($topic_id) {
			$query->where('a.topic_id = '. $topic_id);
		}

		// Filter by published state
		$published = $this->getState('filter.state');
		if (is_numeric($published)) {
			$query->where('a.state = '.(int) $published);
		} elseif ($published === '') {
			$query->where('(a.state IN (0, 1))');
		}

		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where('a.title LIKE ' . $search);
			}
		}

		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering', 'ordering');
		$orderDirn	= $this->state->get('list.direction', 'asc');
		if ($orderCol == 'ordering') {
			$orderCol = 't.ordering ' . $orderDirn . ', a.ordering';
		}
		$query->order($db->escape($orderCol . ' ' . $orderDirn));

		return $query;
	}

	/**
	* Function to get the Check
	*
	* @return Table object
	*/
	public function getCheck()
	{
		if (!$this->_check) {
			$app = JFactory::getApplication();
			$id = $app->input->getInt('id', 0);
			if (!$id) {
				return false;
			}
			$this->_check = $this->getTable('check');
			$this->_check->load($id);

			if (! $this->_check->id) {
				$uri = 'index.php?option=com_roughcheck&view=checks';
				$route = JRoute::_($uri, false);
				$message = JText::_('COM_ROUGHCHECK_ERROR_REQUIRE_CHECK');
				$messageType = 'error';
				$app->redirect($route, $message, $messageType);
				return true;
			}
		}
		return $this->_check;
	}

	/**
	* Returns existance of topics
	*
	* @return bool True if existing data, false if there is none
	*/
	public function getHasTopics()
	{
		$check = $this->getCheck();
		if (!$check){
			return false;
		}
		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('count(*)');
		$query->from('#__roughcheck_check_topics AS a');
		$query->where('a.check_id = ' . (int) $check->id);
		$query->where('a.state = 1');

		$db->setQuery($query);
		$count = $db->loadResult();

		if ($count > 0) {
			return true;
		} else {
			return false;
		}
	}

	/**
	* Returns topics
	*
	* @return array Object array of topics for this question
	*/
	public function getTopics()
	{
		$options = array();

		$check = $this->getCheck();
		if (!$check){
			return false;
		}
		try {
			$db = $this->getDbo();
			$query	= $db->getQuery(true);

			$query->select('a.id AS value, a.title AS text');
			$query->from('#__roughcheck_check_topics AS a');
			$query->where('a.state IN (0,1)');

			//$id = $this->form->getValue('check_id', 0);
			$query->where('a.check_id = ' . (int) $check->id);

			$query->order('a.ordering ASC');

			// Get the options.
			$db->setQuery($query);

			return $db->loadObjectList();
		} catch (Exception $e) {
			JLog::add('Exception: '.$e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			$this->setError($e->getMessage());
			return false;
		}
	}

}
