<?php
/**
* Check topic model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checktopic.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Check topic model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelChecktopic extends JModelAdmin
{
	/**
	* Object variable to store saved parent
	*
	* @var JTable Object loaded with parent record
	*/
	private $_parent;

	/**
	* Method to test whether a record can be deleted.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to delete the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canDelete($record)
	{
		if (!empty($record->id)) {
			if ($record->state != -2) {
				return ;
			}
			$user = JFactory::getUser();

			$table = $this->getTable('check');
			$table->load($record->check_id);

			$categoryId = 0;
			if ($table->id) {
				$categoryId = $table->catid;
			}

			if ($categoryId) {
				return $user->authorise(
					'core.delete',
					'com_roughcheck.category.'.(int) $categoryId
				);
			} else {
				return parent::canDelete($record);
			}
		}
	}

	/**
	* Method to test whether a record can have its state changed.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to change the state of the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canEditState($record)
	{
		$user = JFactory::getUser();

		$categoryId = 0;

		if (!empty($record->id)) {
			$table = $this->getTable('check');
			$table->load($record->check_id);

			if ($table->id) {
				$categoryId = $table->catid;
			}
		}

		if ($categoryId) {
			return $user->authorise(
				'core.edit.state',
				'com_roughcheck.category.' . $categoryId
			);
		} else {
			return parent::canEditState($record);
		}
	}

	/**
	* Method to get the form record.
	*
	* @param array   $data     Data for the form.
	* @param boolean $loadData True if the form is to load its own data
	*                          (default case), false if not.
	*
	* @return mixed A JForm object on success, false on failure
	*/
	public function getForm($data = array(), $loadData = true) 
	{
		// Get the form.
		$form = $this->loadForm(
			'com_roughcheck.checktopic', 'checktopic',
			array('control' => 'jform', 'load_data' => $loadData)
		);
		if (empty($form)) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add(
				'There is no form!',
				JLog::ERROR, COM_ROUGHCHECK
			);
			throw new Exception('There is no form!');
			return false;
		}

		// Determine correct permissions to check.
		if ($this->getState('checktopic.id')) {
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('checktopic', 'action', 'core.edit');
		} else {
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('checktopic', 'action', 'core.create');
		}

		// Modify the form based on access controls.
		if (!$this->canEditState((object) $data)) {
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
		}

		return $form;
	}

	/**
	* Method to get the data that should be injected in the form.
	*
	* @return mixed The data for the form.
	*/
	protected function loadFormData() 
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState(
			'com_roughcheck.edit.checktopic.data', array()
		);
		if (empty($data)) {
			$data = $this->getItem();
		}

		// Prime some default values.
		if ($data->id == 0) {
			$parent = $this->getParent();
			if (!$parent) {
				JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
				JLog::add(
					'Creating Topic with unknown parent!',
					JLog::ERROR, COM_ROUGHCHECK
				);
				throw new Exception('An error occured');
			}
			$data->set('check_id', $parent->id);
		}

		return $data;
	}

	/**
	* Function to get the parent
	*
	* @return JTable object
	*/
	public function getParent()
	{
		if (! $this->_parent) {
			$check_id = 0;
			$item = $this->getItem();
			if ($item->check_id) {
				$check_id = $item->check_id;
			} else {
				$context = "$this->option.edit.$this->name";
				$app = JFactory::getApplication();
				$check_id = $app->getUserState("$context.check_id", 0);
			}
			if (!$check_id) {
				return false;
			}
			$this->_parent = $this->getTable('check');
			$this->_parent->load($check_id);
		}
		return $this->_parent;
	}
}
