<?php
/**
* Check topics model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checktopics.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Check topics model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelChecktopics extends JModelList
{

	/**
	* Constructor
	*
	* @param array $config An optional associative array of configuration settings.
	*
	* @see   JController
	*/
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'a.id',
				'title', 'a.title',
				'check_id',
				'description', 'a.description',
				'state', 'a.state',
				'ordering', 'a.ordering',
				'access', 'a.access', 'access_level',
				'created', 'a.created',
				'created_by', 'a.created_by',
				);
		}

		parent::__construct($config);
	}

	/**
	* Method to auto-populate the model state.
	*
	* This method should only be called once per instantiation and is designed
	* to be called on the first call to the getState() method unless the model
	* configuration flag to ignore the request is set.
	*
	* Note. Calling getState in this method will result in recursion.
	*
	* @param string $ordering  An optional ordering field.
	* @param string $direction An optional direction (asc|desc).
	*
	* @return  void
	*/
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $this->getUserStateFromRequest(
			$this->context.'.filter.search', 'filter_search'
		);
		$this->setState('filter.search', $search);

		$accessId = $this->getUserStateFromRequest(
			$this->context.'.filter.access', 'filter_access', null, 'int'
		);
		$this->setState('filter.access', $accessId);

		$published = $this->getUserStateFromRequest(
			$this->context.'.filter.state', 'filter_published', '', 'string'
		);
		$this->setState('filter.state', $published);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_roughcheck');
		$this->setState('params', $params);

		// List state information.
		parent::populateState($ordering, $direction);
	}

	/**
	* Returns list query
	*
	* @return string sql list query
	*/
	protected function getListQuery()
	{
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id,a.ordering');
		$query->select('a.check_id, a.title');
		$query->select('a.state');
		$query->select('a.publish_up, a.publish_down');
		$query->select('a.checked_out, a.checked_out_time');
		$query->select('a.description');
		$query->select(
			' ( select count(*)'
			. ' from   #__roughcheck_check_questions q'
			. ' where  q.topic_id = a.id'
			.') as countofquestions'
		);
		$query->from($db->quoteName('#__roughcheck_check_topics').' AS a');

		$app = JFactory::getApplication();
		$check_id = $app->input->getInt('id', 0);
		if ($check_id) {
			$query->where(
				'(a.check_id = ' . $check_id . ')'
			);
		}

		// Join over the users for the checked out user.
		$query->select('uc.name AS editor');
		$query->join(
			'LEFT',
			$db->quoteName('#__users') . ' AS uc ON uc.id=a.checked_out'
		);

		// Filter by published state
		$published = $this->getState('filter.state');
		if (is_numeric($published)) {
			$query->where('a.state = '.(int) $published);
		} elseif ($published === '') {
			$query->where('(a.state IN (0, 1))');
		}

		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where(
					'(a.title LIKE ' . $search
					.' OR a.description LIKE ' . $search . ')'
				);
			}
		}

		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering', 'ordering');
		$orderDirn	= $this->state->get('list.direction', 'asc');
		$query->order($db->escape($orderCol . ' ' . $orderDirn));

		return $query;
	}

	/**
	* Function to get the parent
	*
	* @return Table object
	*/
	public function getParent()
	{
		$app = JFactory::getApplication();
		$id = $app->input->getInt('id', 0);
		if (!$id) {
			return false;
		}
		$parent = $this->getTable('check');
		$parent->load($id);

		if (! $parent->id) {
			$uri = 'index.php?option=com_roughcheck&view=checks';
			$route = JRoute::_($uri, false);
			$message = JText::_('COM_ROUGHCHECK_ERROR_REQUIRE_CHECK');
			$messageType = 'error';
			$app->redirect($route, $message, $messageType);
			return true;
		}

		return $parent;
	}
}
