<?php
/**
* Modal dialogue to get Roughcheck Check id
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checks.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/
 
defined('_JEXEC') or die('Restricted access');

// Not called via our component, so need to re-define
define('COM_ROUGHCHECK', 'com_roughcheck');

// Log com_roughcheck errors only.
JLog::addLogger(
    array(
        'text_file' => COM_ROUGHCHECK.'.php'
    ),
    JLog::ALL,
	COM_ROUGHCHECK
);

/**
* Modal dialogue to get Roughcheck Check id
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @license    GNU General Public License version 3 or later; see LICENSE.txt
* @link       http://p-o.co.uk/
*/
class JFormFieldModal_Checks extends JFormField
{
    /**
    * The form field type.
    *
    */
    protected $type = 'Modal_Checks';

    /**
    * Method to get the field input markup.
    *
    * @return	string	The field input markup.
    */
    protected function getInput()
    {
		// Load the javascript
		JHtml::_('behavior.framework');
		JHtml::_('behavior.modal', 'a.modal');
		JHtml::_('bootstrap.tooltip');

		// Build the script.
		$script = array();
		$script[] = '	function jSelectCheck_'.$this->id.'(id, name, object) {';
		$script[] = '		document.id("'.$this->id.'_id").value = id;';
		$script[] = '		document.id("'.$this->id.'_name").value = name;';
		$script[] = '		SqueezeBox.close();';
		$script[] = '	}';

		// Add the script to the document head.
		JFactory::getDocument()->addScriptDeclaration(implode("\n", $script));

		// Get the title of the linked check
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('title');
		$query->from($db->quoteName('#__roughcheck_checks'));
		$query->where('id = '.(int) $this->value);
		$db->setQuery($query);

		try {
			$title = $db->loadResult();
			if ($db->getErrorMsg()) {
				throw new Exception($db->getErrorMsg());
			}
		} catch (Exception $e) {
			JLog::add('Exception: '.$e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			JError::raiseWarning(500, $e->getMessage);
		}

        if (empty($title)) {
            $title = JText::_('COM_ROUGHCHECK_SELECT_ROUGHCHECK_CHECK');
        }
        $title = htmlspecialchars($title, ENT_QUOTES, 'UTF-8');

        // The current Roughcheck check display field.
        // Setup variables for display.
        $html	= array();
        $link	= 'index.php?option=com_roughcheck&amp;'
            .'view=checks&amp;layout=modal'
            .'&amp;tmpl=component'
            .'&amp;layout=modal'
            .'&amp;function=jSelectCheck_'.$this->id;
		if (isset($this->element['language']))
		{
			$link .= '&amp;forcedLanguage='.$this->element['language'];
		}
        $html[] = '<span class="input-append">';
        $html[] = '  <input type="text"'
            .' class="input-medium" '
            .' id="'.$this->id.'_name" '
            .' value="'.$title.'" '
            .' disabled="disabled" />';

        // The user select button.
        $html[] = '<a class="modal btn"'
			.' title="'.JText::_('COM_ROUGHCHECK_CHANGE_ROUGHCHECK_CHECK').'"'
            .' href="'.$link.'" '
            .' rel="{handler: \'iframe\', size: {x: 800, y: 450}}">'
			.'<i class="icon-file hasTooltip"'
			. ' title="'.JText::_('COM_ROUGHCHECK_CHANGE_ROUGHCHECK_CHECK').'"'
			.'></i> '.JText::_('JSELECT').'</a>';
        $html[] = '</span>';

        // The active check id field.
        if (0 == (int)$this->value) {
            $value = '';
        } else {
            $value = (int)$this->value;
        }

        // class='required' for client side validation
        $class = '';
        if ($this->required) {
            $class = ' class="required modal-value"';
        }

        $html[] = '<input type="hidden" id="'
            .$this->id.'_id"' . $class
            .' name="'.$this->name
            .'" value="'.$value.'" />';

        return implode("\n", $html);

    }

}
