<?php
/**
* Rewarddetail model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: rewarddetail.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Rewarddetail model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelRewarddetail extends JModelAdmin
{

	protected $_item;

	/**
	* Method to test whether a record can be deleted.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to delete the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canDelete($record)
	{
		if (!empty($record->id)) {
			if ($record->state != -2) {
				return ;
			}
			$user = JFactory::getUser();

			return parent::canDelete($record);
		}
	}

	/**
	* Method to get the form record.
	*
	* @param array   $data     Data for the form.
	* @param boolean $loadData True if the form is to load its own data
	*                          (default case), false if not.
	*
	* @return mixed A JForm object on success, false on failure
	*/
	public function getForm($data = array(), $loadData = true) 
	{
		// Get the form.
		$form = $this->loadForm(
			'com_roughcheck.rewarddetail', 'rewarddetail',
			array('control' => 'jform', 'load_data' => $loadData)
		);
		if (empty($form)) {
			return false;
		}

		// Determine correct permissions to check.
		if ($this->getState('rewarddetail.id')) {
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('id', 'action', 'core.edit');
		} else {
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('id', 'action', 'core.create');
		}

		// Modify the form based on access controls.
		if (!$this->canEditState((object) $data)) {
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
		}

		return $form;
	}

	/**
	* Method to get the data that should be injected in the form.
	*
	* @return mixed The data for the form.
	*/
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState(
			'com_roughcheck.edit.rewarddetail.data', array()
		);
		if (empty($data)) {
			$data = $this->getItem();
		}

		return $data;
	}

	/**
	* Method to get an array of data items.
	*
	* @return mixed An array of data items on success, false on failure.
	*/
	public function getReward()
	{
		$table = $this->getTable('reward');
		if ($this->_item) {
			$table->load($this->_item->reward_profile_id);
		} else {
			$app = JFactory::getApplication();
			$reward_profile_id = $app->input->getInt('reward_profile_id', 0);
			$table->load($reward_profile_id);
		}

		return $table;
	}

	/**
	* Method to get a single record.
	*
	* @param integer $pk The id of the primary key.
	*
	* @return mixed Object on success, false on failure.
	*/
	public function getItem($pk = null)
	{
		if ($this->_item) {
			return $this->_item;
		} else {
			$pk = (!empty($pk)) ? $pk : (int) $this->getState($this->getName() . '.id');
			$this->_item = parent::getItem($pk);

			if (!$this->_item) {
				$this->_item = $this->getTable();
			}
			if (!$this->_item->reward_profile_id) {
				$app = JFactory::getApplication();
				$reward_profile_id = $app->input->getInt('reward_profile_id', 0);
				$this->_item->reward_profile_id = $reward_profile_id;
			}

			return $this->_item;
		}
	}
}
