<?php
/**
* Help types view
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: view.html.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Help types view class
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckViewHelps extends JViewLegacy
{
	protected $items;
	protected $state;
	protected $pagination;
	protected $sidebar;

	/**
	* Display method for Help Types
	*
	* @param string $tpl Template to display
	*
	* @return void
	**/
	function display($tpl = null)
	{
		// Get data from the model
		$this->items = $this->get('Items');
		$this->state = $this->get('State');
		$this->pagination = $this->get('Pagination');

		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			foreach ($errors as $error) {
				JLog::add($error, JLog::ERROR, COM_ROUGHCHECK);
			}
			throw new Exception('An error occured');
			return false;
		}

		$this->addToolBar();
		$this->sidebar = JHtmlSidebar::render();

		parent::display($tpl);
	}

	/**
	* Setting the toolbar
	*
	* @return void
	*/
	protected function addToolbar()
	{

		JToolBarHelper::title(
			JText::_('COM_ROUGHCHECK_HELPS_HEADING'), 'article'
		);

		$state	= $this->get('State');
		$canDo	= RoughcheckHelper::getActions();
		$user	= JFactory::getUser();

		if ($canDo->get('core.create')) {
			JToolBarHelper::addNew('help.add', 'JTOOLBAR_NEW');
		}
		if ($canDo->get('core.edit')) {
			JToolBarHelper::editList('help.edit', 'JTOOLBAR_EDIT');
			JToolBarHelper::divider();
		}
		if ($canDo->get('core.edit.state')) {
			JToolBarHelper::publish('helps.publish', 'JTOOLBAR_PUBLISH', true);
			JToolBarHelper::unpublish('helps.unpublish', 'JTOOLBAR_UNPUBLISH', true);

			JToolBarHelper::divider();
			JToolBarHelper::archiveList('helps.archive');
			JToolBarHelper::checkin('helps.checkin');
		}

		if ($state->get('filter.state') == -2 && $canDo->get('core.delete')) {
			JToolBarHelper::deleteList('', 'helps.delete', 'JTOOLBAR_EMPTY_TRASH');
			JToolBarHelper::divider();
		} else if ($canDo->get('core.edit.state')) {
			JToolBarHelper::trash('helps.trash');
			JToolBarHelper::divider();
		}

		if ($canDo->get('core.admin')) {
			JToolBarHelper::preferences('com_roughcheck');
			JToolBarHelper::divider();
		}

		JToolBarHelper::help('helptypes', true);

		JHtmlSidebar::setAction('index.php?option=com_roughcheck&view=helps');

		JHtmlSidebar::addFilter(
			JText::_('JOPTION_SELECT_PUBLISHED'),
			'filter_published',
			JHtml::_('select.options', JHtml::_('jgrid.publishedOptions'), 'value', 'text', $this->state->get('filter.published'), true)
		);

		JHtmlSidebar::addFilter(
			JText::_('JOPTION_SELECT_LANGUAGE'),
			'filter_language',
			JHtml::_('select.options', JHtml::_('contentlanguage.existing', true, true), 'value', 'text', $this->state->get('filter.language'))
		);

	}

	/**
	* Returns an array of fields the table can be sorted by
	*
	* @return  array  Array containing the field name to sort by as the key and display text as value
	*/
	protected function getSortFields()
	{
		return array(
			'a.ordering' => JText::_('JGRID_HEADING_ORDERING'),
			'a.state' => JText::_('JSTATUS'),
			'a.title' => JText::_('JGLOBAL_TITLE'),
			'a.id' => JText::_('JGRID_HEADING_ID'),
		);
	}
}
