<?php
/**
* Rouchcheck helper
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: roughcheck.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Roughcheck helper
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckHelper
{

	protected static $lookup;

	/**
	* Gets a list of the actions that can be performed.
	*
	* @param int $categoryId The category ID.
	* @param int $checkId    The check ID.
	*
	* @return JObject Actions object
	*/
	public static function getActions($categoryId = 0, $checkId = 0)
	{
		$user	= JFactory::getUser();
		$result	= new JObject;

		if (empty($checkId) && empty($categoryId)) {
			$assetName = COM_ROUGHCHECK;
		} elseif (empty($checkId)) {
			$assetName = COM_ROUGHCHECK . '.category.' . (int) $categoryId;
		} else {
			$assetName = COM_ROUGHCHECK . '.check.' . (int) $checkId;
		}

		$actions = array(
			'core.admin', 'core.manage', 'core.create',
			'core.edit', 'core.edit.own', 'core.edit.state', 'core.delete',
			'assessment.create', 'assessment.delete', 'assessment.edit',
			'assessment.edit.own', 'assessment.edit.state', 'assessment.edit.xref', 
			'assessment.manage'
		);

		foreach ($actions as $action) {
			$result->set($action, $user->authorise($action, $assetName));
		}

		return $result;
	}

	/**
	* Gets a list of the actions that can be performed on an assessment.
	*
	* @param int $assessmentId The assessment ID.
	* @param int $checkId      The check ID.
	*
	* @return JObject Actions object
	*/
	public static function getAssessmentActions($assessmentId = 0, $checkId = 0)
	{
		$user	= JFactory::getUser();
		$result	= new JObject;

		if (empty($checkId) && empty($assessmentId)) {
			$assetName = COM_ROUGHCHECK;
		} elseif (empty($checkId)) {
			$assetName = COM_ROUGHCHECK . '.assessment.' . (int) $assessmentId;
		} else {
			$assetName = COM_ROUGHCHECK . '.check.' . (int) $checkId;
		}

		$actions = array(
			'assessment.create', 'assessment.delete', 'assessment.edit',
			'assessment.edit.own', 'assessment.edit.state', 'assessment.edit.xref',
			'assessment.manage'
		);

		foreach ($actions as $action) {
			$result->set($action, $user->authorise($action, $assetName));
		}

		return $result;
	}

	/**
	* Gets a list of the actions that can be performed on an assessment.
	*
	* @param int $catid    The category ID.
	* @param int $language The language ID.
	*
	* @return JObject Actions object
	*/
	public static function getCategoryRoute($catid, $language = 0)
	{
		if ($catid instanceof JCategoryNode)
		{
			$id = $catid->id;
			$category = $catid;
		}
		else
		{
			$id = (int) $catid;
			$category = JCategories::getInstance('Roughcheck')->get($id);
		}

		if ($id < 1)
		{
			$link = '';
		}
		else
		{
			//Create the link
			$link = 'index.php?option=com_roughcheck&view=category&id='.$id;
			$needles = array(
				'category' => array($id)
			);

			if ($language && $language != "*" && JLanguageMultilang::isEnabled())
			{
				$db		= JFactory::getDbo();
				$query	= $db->getQuery(true)
					->select('a.sef AS sef')
					->select('a.lang_code AS lang_code')
					->from('#__languages AS a');

				$db->setQuery($query);
				$langs = $db->loadObjectList();
				foreach ($langs as $lang)
				{
					if ($language == $lang->lang_code)
					{
						$link .= '&lang='.$lang->sef;
						$needles['language'] = $language;
					}
				}
			}

			if ($item = self::_findItem($needles))
			{
				$link .= '&Itemid='.$item;
			}
			else
			{
				if ($category)
				{
					$catids = array_reverse($category->getPath());
					$needles = array(
						'category' => $catids,
						'categories' => $catids
					);
					if ($item = self::_findItem($needles))
					{
						$link .= '&Itemid='.$item;
					}
					elseif ($item = self::_findItem())
					{
						$link .= '&Itemid='.$item;
					}
				}
			}
		}

		return $link;
	}

	protected static function _findItem($needles = null)
	{
		$app		= JFactory::getApplication();
		$menus		= $app->getMenu('site');
		$language	= isset($needles['language']) ? $needles['language'] : '*';

		// Prepare the reverse lookup array.
		if (!isset(self::$lookup[$language]))
		{
			self::$lookup[$language] = array();

			$component	= JComponentHelper::getComponent('com_roughcheck');

			$attributes = array('component_id');
			$values = array($component->id);

			if ($language != '*')
			{
				$attributes[] = 'language';
				$values[] = array($needles['language'], '*');
			}

			$items = $menus->getItems($attributes, $values);

			foreach ($items as $item)
			{
				if (isset($item->query) && isset($item->query['view']))
				{
					$view = $item->query['view'];
					if (!isset(self::$lookup[$language][$view]))
					{
						self::$lookup[$language][$view] = array();
					}
					if (isset($item->query['id']))
					{

						// here it will become a bit tricky
						// language != * can override existing entries
						// language == * cannot override existing entries
						if (!isset(self::$lookup[$language][$view][$item->query['id']]) || $item->language != '*')
						{
							self::$lookup[$language][$view][$item->query['id']] = $item->id;
						}
					}
				}
			}
		}

		if ($needles)
		{
			foreach ($needles as $view => $ids)
			{
				if (isset(self::$lookup[$language][$view]))
				{
					foreach ($ids as $id)
					{
						if (isset(self::$lookup[$language][$view][(int) $id]))
						{
							return self::$lookup[$language][$view][(int) $id];
						}
					}
				}
			}
		}

		$active = $menus->getActive();
		if ($active && ($active->language == '*' || !JLanguageMultilang::isEnabled()))
		{
			return $active->id;
		}

		// if not found, return language specific home link
		$default = $menus->getDefault($language);
		return !empty($default->id) ? $default->id : null;
	}

	/**
	* generate Unique Universal IDentifier
	*
	* @return string a new UUID
	*/
	public static function uuid()
	{
		// use uuid extension from PECL if available
		if (function_exists("uuid_create")) {
			return uuid_create();
		}

		// fallback
		// this should be random enough for now
		$uuid = md5(microtime().getmypid());

		// set variant and version fields for 'true' random uuid
		$uuid{12} = "4";
		$n = 8 + (ord($uuid{16}) & 3);
		$hex = "0123456789abcdef";
		$uuid{16} = $hex{$n};

		// return formated uuid
		return substr($uuid,  0, 8)."-"
			.  substr($uuid,  8, 4)."-"
			.  substr($uuid, 12, 4)."-"
			.  substr($uuid, 16, 4)."-"
			.  substr($uuid, 20);
	}
}
