<?php
/**
* Assessment model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessment.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelAssessment extends JModelAdmin
{

	/**
	* Object variable to store saved check
	*
	* @var JTable Object loaded with check record
	*/
	private $_check = null;

	/**
	* Method to test whether a record can be deleted.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to delete the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canDelete($record)
	{
		if (!empty($record->id)) {
			if ($record->state != -2) {
				return ;
			}
			$user = JFactory::getUser();
			$asset = 'com_roughcheck.assessment.'.(int) $record->id;
			return $user->authorise('assessment.delete', $asset);
		}
	}

	/**
	* Method to test whether a record can have its state changed.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to change the state of the record.
	*                 Defaults to the permission set in the component.
	*/
	public function canEditState($record)
	{
		$app = JFactory::getApplication();
		$user = JFactory::getUser();
		$table = $this->getTable();
		if ($record->id) {
			$table->load($record->id);
		} else {
			// Check asset create permissions if new assessment
			$asset = COM_ROUGHCHECK.'.check.id';
			$check_id = $app->getUserState($asset);
			if ($check_id) {
				$asset = COM_ROUGHCHECK.'.check.'.$check_id;
			} else {
				$asset = COM_ROUGHCHECK;
			}
			$ret = $user->authorise('assessment.create', $asset);
			return $ret;
		}

		// We have an assessment so check the authorization
		$userId = $user->get('id');
		$asset	= 'com_roughcheck.assessment.' . $record->id;
		$userXref = $app->getUserState($asset);
		if ($user->authorise('assessment.edit', $asset)) {
			// User is allowed access
			JLog::add('Access via assessment.edit', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (
			!empty($userId)
			&& $user->authorise('assessment.edit.own', $asset)
			&& $userId == $table->created_by
		) {
			// User is allowed access to own assessment
			JLog::add('Access via assessment.edit.own', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (
			!empty($userXref)
			&& $userXref == $table->xreference
			&& $user->authorise('assessment.edit.xref', $asset)
		) {
			// User is allowed access via xreference
			JLog::add('Access via xref', JLog::DEBUG, COM_ROUGHCHECK);
		} else {
			// User is not allowed access to this assessment
			JLog::add('No access to: ' . $asset, JLog::DEBUG, COM_ROUGHCHECK);
 			return false;
		}
		return true;
	}

	/**
	* Method to get the form record.
	*
	* @param array   $data     Data for the form.
	* @param boolean $loadData True if the form is to load its own data
	*                          (default case), false if not.
	*
	* @return mixed A JForm object on success, false on failure
	*/
	public function getForm($data = array(), $loadData = true) 
	{
		// Get the form.
		$app = JFactory::getApplication();
		$layout = $app->input->getCmd('layout', 'default');
		$id = $app->input->getInt('id', 0);
		$checkId = $app->getUserState('com_roughcheck.check.id', 0);
		$source = '';
		if ($layout == 'xref') {
			$source = 'xref';
			$loadData = false;
		} elseif ($id) {
			$source = 'assessment';
		} else {
			$loadData = false;
			$source = 'assessment';
		}

		try {
			$form = $this->loadForm(
				'com_roughcheck.assessment', $source,
				array('control' => 'jform', 'load_data' => $loadData)
			);
		}
		catch (Exception $e)
		{
			JLog::add(
				'Unable to loadForm: '.$e->getMessage(),
				JLog::ERROR, COM_ROUGHCHECK
			);
			$this->setError($e->getMessage());
			return array();
		}
		if (empty($form)) {
			return false;
		}

		// Determine correct permissions to assessment.
		$data['id'] = $form->getValue('id');
		if (isset($data['id'])) {
			$this->setState('assessment.id', $data['id']);
		} else {
			$this->setState('assessment.id', 0);
		}

		// If this is a new record for display, no need to present various fields
		if (isset($data['id']) && $data['id']) {
			$form->setFieldAttribute('check_id', 'readonly', 'true');
			// Remove empty fields
			if (!$form->getValue('created_by')) {
				$form->removeField('created_by');
			}
			if (!$form->getValue('modified_by')) {
				$form->removeField('modified_by');
			}
		} else {
			$form->removeField('created_by');
			$form->removeField('created');
			$form->removeField('modified_by');
			$form->removeField('modified');
			$form->removeField('completed');
			$form->removeField('checked_out');
			$form->removeField('checked_out_time');
			$form->removeField('publish_up');
			$form->removeField('publish_down');
			if ($layout == 'xref') {
				$form->setFieldAttribute('xreference', 'required', 'true');
			} else {
				$form->removeField('xreference');
				$form->removeField('xreferencekey');
			}
		}

		return $form;
	}

	/**
	* Method to get the data that should be injected in the form.
	*
	* @return mixed The data for the form.
	*/
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState(
			'com_roughcheck.edit.assessment.data', array()
		);
		if (empty($data)) {
			try {
				$data = $this->getItem();
				if (!empty($data) && $data->id) {
					$data->xreferencekey = $data->id . '-'. $data->xreference;
				}
			}
			catch (Exception $e)
			{
				JLog::add(
					'Unable to getItem: '.$e->getMessage(),
					JLog::ERROR, COM_ROUGHCHECK
				);
				$this->setError($e->getMessage());
				return array();
			}
		}

		// Prime some default values.
		if ($this->getState('assessment.id') == 0) {
			$app = JFactory::getApplication();
			$check_id_default = $app->getUserState('com_roughcheck.check.id');
			$check_id = $app->input->getInt('check_id', $check_id_default);
			$data->set('check_id', $check_id);
		}

		return $data;
	}

	/**
	* Function to get the parent
	*
	* @return JTable object
	*/
	public function getCheck()
	{
		if (! $this->_check) {
			$app = JFactory::getApplication();
			$check_id = $app->getUserState('com_roughcheck.check.id', 0);
			if (! $check_id) {
				try {
					$item = $this->getItem();
				}
				catch (Exception $e)
				{
					JLog::add(
						'Unable to get assessment to lookup check: '.$e->getMessage(),
						JLog::ERROR, COM_ROUGHCHECK
					);
					$this->setError($e->getMessage());
					return false;
				}
				if (!empty($item) && $item->check_id) {
					$check_id = $item->check_id;
				} else {
					JLog::add(
						'Unable to find assessment to lookup check',
						JLog::DEBUG, COM_ROUGHCHECK
					);
				}
			}
			if (!$check_id) {
				$this->_check = new stdClass;
				$this->_check->id = 0;
				$this->_check->title = '';
				$this->_check->description = '';
				$this->_check->params = '';
			} else {
				$this->_check = $this->getTable('check');
				$this->_check->load($check_id);
			}
		}
		return $this->_check;
	}

	/**
	* Adds a hit
	*
	* @return void
	*/
	function hit()
	{
		$row = $this->getTable();
		$row->load($this->_id);
		return $row->hit($this->_id);
	}

}
