<?php
/**
* Assessment response model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessmentresponse.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment response model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelAssessmentresponse extends JModelAdmin
{

	private $_question;
	private $_assessment;

	/**
	* Method to test whether a record can have its state changed.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to change the state of the record.
	*                 Defaults to the permission set in the component.
	*/
	public function canEditState($record)
	{
		$user = JFactory::getUser();
		$table = $this->getTable();
		if (isset($record->id)) {
			$table->load($record->id);
		} else {
			return false;
		}

		// We have an assessment so check the authorization
		$userId = $user->get('id');
		$asset	= 'com_roughcheck.assessment.' . $record->id;
		$app = JFactory::getApplication();
		$userXref = $app->getUserState($asset);
		if ($user->authorise('assessment.edit', $asset)) {
			// User is allowed access
			JLog::add('Access via assessment.edit', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (
			!empty($userId)
			&& $user->authorise('assessment.edit.own', $asset)
			&& $userId == $table->created_by
		) {
			// User is allowed access to own assessment
			JLog::add('Access via assessment.edit.own', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (
			!empty($userXref)
			&& $userXref == $table->xreference
			&& $user->authorise('assessment.edit.xref', $asset)
		) {
			// User is allowed access via xreference
			JLog::add('Access via xref', JLog::DEBUG, COM_ROUGHCHECK);
		} else {
			// User is not allowed access to this assessment
			JLog::add('No access to: ' . $asset, JLog::DEBUG, COM_ROUGHCHECK);
 			return false;
		}
		return true;
	}

	/**
	* Method to get the form record.
	*
	* @param array   $data     Data for the form.
	* @param boolean $loadData True if the form is to load its own data
	*                          (default case), false if not.
	*
	* @return mixed A JForm object on success, false on failure
	*/
	public function getForm($data = array(), $loadData = true) 
	{
		// Get the form.
		$form = $this->loadForm(
			'com_roughcheck.assessmentresponse', 'assessmentresponse',
			array('control' => 'jform', 'load_data' => $loadData)
		);
		if (empty($form)) {
			return false;
		}

		// Determine correct permissions to assessment.
		if ($this->getState('assessmentresponse.id')) {
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.edit');
		} else {
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.create');
		}

		// Modify the form based on access controls.
		if (!$this->canEditState((object) $data)) {
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');
			$form->setFieldAttribute('publish_up', 'disabled', 'true');
			$form->setFieldAttribute('publish_down', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
			$form->setFieldAttribute('publish_up', 'filter', 'unset');
			$form->setFieldAttribute('publish_down', 'filter', 'unset');
		}

		$app = JFactory::getApplication();
		$input = $app->input;

		if ($input->getCmd('layout', '') == 'modal') {
			// Remove fields for modal notes
			$form->removeField('ordering');
			$form->removeField('state');
			$form->removeField('publish_up');
			$form->removeField('publish_down');
			$form->removeField('risk_detail_id');
			$form->removeField('reward_detail_id');
			$form->removeField('response');
		}

		return $form;
	}

	/**
	* Method to get the data that should be injected in the form.
	*
	* @return mixed The data for the form.
	*/
	protected function loadFormData() 
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState(
			'com_roughcheck.edit.assessmentresponse.data', array()
		);
		if (empty($data)) {
			$data = $this->getItem();
		}

		// convert array to object
		if (is_array($data)) {
			$data = JArrayHelper::toObject($data);
		}

		// Prime some default values.
		if (!$data->assessment_id) {
			$assessment = $this->getAssessment();
			$data->assessment_id = $assessment->id;
		} else {
			$table = $this->getTable('assessment');
			$table->load($data->assessment_id);
			$this->_assessment = $table;
		}
		if (!$data->question_id) {
			$question = $this->getQuestion();
			$data->question_id = $question->id;
		} else {
			$table = $this->getTable('checkquestion');
			$table->load($data->question_id);
			$this->_question = $table;
		}

		return $data;
	}

	/**
	* Method to get an assessment
	*
	* @return JTable object
	*/
	public function getAssessment()
	{

		if ($this->_assessment) {
			return $this->_assessment;
		}

		$app = JFactory::getApplication();
		$id = $app->input->getInt('a', 0);
		$table = $this->getTable('assessment');
		$table->load($id);

		$this->_assessment = $table;
		
		return $this->_assessment;
	}

	/**
	* Method to get a question
	*
	* @return JTable object
	*/
	public function getQuestion()
	{

		if ($this->_question) {
			return $this->_question;
		}

		$app = JFactory::getApplication();
		$input = $app->input;

		$id = $input->getInt('q', 0);
		if ($id) {
			$table = $this->getTable('checkquestion');
			$table->load($id);
			$this->_question = $table;

			return $this->_question;
		}

		$id = $input->getInt('id', 0);
		if ($id) {
			$table = $this->getTable('assessmentresponse');
			$table->load($id);
			$id = $table->question_id;
			$table = $this->getTable('checkquestion');
			$table->load($id);
			$this->_question = $table;

			return $this->_question;
		}
	}

	/**
	* Returns list query
	*
	* @return string sql list query
	*/
	protected function getHelpsQuery()
	{
		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id');
		$query->select('a.question_id');
		$query->select('a.help_type_id');
		$query->select('a.ordering');
		$query->select('a.title');
		$query->select('a.state');
		$query->select('a.checked_out, a.checked_out_time');
		$query->select('a.created, a.created_by');
		$query->select('a.modified, a.modified_by');
		$query->select('a.description');
		$query->from($db->quoteName('#__roughcheck_question_help').' AS a');

		$query->select('ht.title as help_type');
		$query->join(
			'INNER',
			$db->quoteName('#__roughcheck_help_types')
			. ' AS ht ON ht.id=a.help_type_id'
		);

		$question = $this->getQuestion();
		if (isset($question->id)) {
			$query->where('a.question_id = ' . (int)$question->id);
		} else {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add(
				'Listing Question help without question_id',
				JLog::ERROR, COM_ROUGHCHECK
			);
		}
		$query->where('a.state = 1');

		$query->order('a.ordering');

		return $query;
	}

	/**
	* Returns list of risks
	*
	* @return array List of risk objects
	*/
	public function getHelps()
	{
		$db = $this->getDbo();
		$db->setQuery($this->getHelpsQuery());
		$return = $db->loadObjectList();
		return $return;
	}

	/**
	 * Method to save the form data.
	 *
	 * @param array $data The form data.
	 *
	 * @return boolean True on success, False on error.
	 */
	public function save($data)
	{
		// Find response in case it has been created after showing form
		$table = $this->getTable();
		$key = $table->getKeyName();
		if (empty($data[$key])) {
			$db = $this->getDbo();
			$query = $db->getQuery(true);
			$query->select($key);
			$query->from('#__roughcheck_assessment_responses');
			$query->where('assessment_id = ' . (int) $data['assessment_id']);
			$query->where('question_id = ' . (int) $data['question_id']);
			$db->setQuery($query);
			$response = $db->loadObject();
			if ($response) {
				$data[$key] = $response->$key;
			}
		}

		return parent::save($data);
	}
}
