<?php
/**
* Model to show Roughcheck check
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: check.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Check model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelCheck extends JModelAdmin
{

	/**
	* Item cache
	*/
	protected $_item;

	/**
	* Method to test whether a record can be deleted.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to delete the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canDelete($record)
	{
		if (!empty($record->id)) {
			if ($record->state != -2) {
				return ;
			}
			$user = JFactory::getUser();

			if ($record->catid) {
				return $user->authorise(
					'core.delete',
					'com_roughcheck.category.'.(int) $record->catid
				);
			} else {
				return parent::canDelete($record);
			}
		}
	}

	/**
	* Method to test whether a record can have its state changed.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to change the state of the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canEditState($record)
	{
		$user = JFactory::getUser();

		// Check for existing roughcheck.
		if (!empty($record->id)) {
			return $user->authorise(
				'core.edit.state',
				'com_roughcheck.check.' . (int) $record->id
			);
		} elseif (!empty($record->catid)) {
			return $user->authorise(
				'core.edit.state',
				'com_roughcheck.category.' . (int) $record->catid
			);
		} else {
			return parent::canEditState($record);
		}
	}

	/**
	* Method to get the form record.
	*
	* @param array   $data     Data for the form.
	* @param boolean $loadData True if the form is to load its own data
	*                          (default case), false if not.
	*
	* @return mixed A JForm object on success, false on failure
	*/
	public function getForm($data = array(), $loadData = true) 
	{
		// Get the form.
		$form = $this->loadForm(
			'com_roughcheck.check', 'check',
			array('control' => 'jform', 'load_data' => $loadData)
		);
		if (empty($form)) {
			return false;
		}

		// Determine correct permissions to check.
		if ($this->getState('check.id')) {
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.edit');
		} else {
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.create');
		}

		// Modify the form based on access controls.
		if (!$this->canEditState((object) $data)) {
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');
			$form->setFieldAttribute('publish_up', 'disabled', 'true');
			$form->setFieldAttribute('publish_down', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
			$form->setFieldAttribute('publish_up', 'filter', 'unset');
			$form->setFieldAttribute('publish_down', 'filter', 'unset');
		}

		return $form;
	}

	/**
	* Method to get the data that should be injected in the form.
	*
	* @return mixed The data for the form.
	*/
	protected function loadFormData() 
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState(
			'com_roughcheck.edit.roughcheck.data', array()
		);
		if (empty($data)) {
			$data = $this->getItem();
		}

		// Prime some default values.
		if ($this->getState('check.id') == 0) {
			$app = JFactory::getApplication();
			$catid_default = $app->getUserState('com_roughcheck.checks.filter.category_id');
			$catid = $app->input->getInt('catid', $catid_default);
			$data->set('catid', $catid);
		}

		return $data;
	}

	/**
	* Method to get a single record.
	*
	* @param	integer	The id of the primary key.
	*
	* @return	mixed	Object on success, false on failure.
	*/
	public function getItem($pk = null)
	{
		if (!isset($this->_item)) {
			if ($this->_item = parent::getItem($pk)) {
				// Convert the params field to an array.
				$registry = new JRegistry;
				$registry->loadString($this->_item->metadata);
				$this->_item->metadata = $registry->toArray();
			}
		}
		return $this->_item;
	}

	/**
	* Adds a hit
	*
	* @return void
	*/
	function hit()
	{
		$row = $this->getTable();
		$row->load($this->_id);
		return $row->hit($this->_id);
	}

}
