<?php
/**
* Checks model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checks.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Checks model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelChecks extends JModelList
{

	/**
	* Constructor
	*
	* @param array $config An optional associative array of configuration settings.
	*
	* @see   JController
	*/
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'a.id',
				'a.title',
				'category_title',
				'access_level',
				'a.state',
				'a.ordering',
				'a.access',
				'a.language',
				'a.hits',
				);
		}

		parent::__construct($config);
	}

	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param string $ordering  An optional ordering field.
	 * @param string $direction An optional direction (asc|desc).
	 *
	 * @return  void
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $this->getUserStateFromRequest(
			$this->context.'.filter.search', 'filter_search'
		);
		$this->setState('filter.search', $search);

		$accessId = $this->getUserStateFromRequest(
			$this->context.'.filter.access', 'filter_access', null, 'int'
		);
		$this->setState('filter.access', $accessId);

		$published = $this->getUserStateFromRequest(
			$this->context.'.filter.state', 'filter_published', '', 'string'
		);
		$this->setState('filter.state', $published);

		$categoryId = $this->getUserStateFromRequest(
			$this->context.'.filter.category_id', 'filter_category_id', ''
		);
		$this->setState('filter.category_id', $categoryId);

		$language = $this->getUserStateFromRequest(
			$this->context.'.filter.language', 'filter_language', ''
		);
		$this->setState('filter.language', $language);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_roughcheck');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('a.title', 'asc');
	}

	/**
	* Returns list query
	*
	* @return string sql list query
	*/
	protected function getListQuery()
	{
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id,a.ordering');
		$query->select('a.title, a.alias, a.catid');
		$query->select('a.hits');
		$query->select('a.state, a.featured, a.access');
		$query->select('a.language, a.publish_up, a.publish_down');
		$query->select('a.created, a.created_by');
		$query->select('a.checked_out, a.checked_out_time');
		$query->select('a.description');
		$query->select(
			' ( select count(*)'
			. ' from   #__roughcheck_check_questions q'
			. ' where  q.check_id = a.id'
			.') as countofquestions'
		);
		$query->select(
			' ( select count(*)'
			. ' from   #__roughcheck_check_topics t'
			. ' where  t.check_id = a.id'
			.') as countoftopics'
		);
		$query->select(
			' ( select count(*)'
			. ' from   #__roughcheck_assessments ass'
			. ' where  ass.check_id = a.id'
			.') as countofassessments'
		);
		$query->from('#__roughcheck_checks AS a');

		// Join over the language
		$query->select('l.title AS language_title');
		$query->join('LEFT', '#__languages AS l ON l.lang_code = a.language');

		// Join over the users for the checked out user.
		$query->select('uc.name AS editor');
		$query->join('LEFT', '#__users AS uc ON uc.id=a.checked_out');

		// Join over the asset groups.
		$query->select('ag.title AS access_level');
		$query->join('LEFT', '#__viewlevels AS ag ON ag.id = a.access');

		// Join over the categories.
		$query->select('c.title AS category_title');
		$query->join('LEFT', '#__categories AS c ON c.id = a.catid');

		// Join over the users for the author.
		$query->select('ua.name AS author_name')
			->join('LEFT', '#__users AS ua ON ua.id = a.created_by');

		// Filter by access level.
		if ($access = $this->getState('filter.access')) {
			$query->where('a.access = '.(int) $access);
		}

		// Implement View Level Access
		$user = JFactory::getUser();
		if (!$user->authorise('core.admin')) {
		    $groups	= implode(',', $user->getAuthorisedViewLevels());
			$query->where('a.access IN ('.$groups.')');
		}

		// Filter by published state
		$published = $this->getState('filter.state');
		if (is_numeric($published)) {
			$query->where('a.state = '.(int) $published);
		} elseif ($published === '') {
			$query->where('(a.state IN (0, 1))');
		}

		// Filter by category.
		$categoryId = $this->getState('filter.category_id');
		if (is_numeric($categoryId)) {
			$query->where('a.catid = '.(int) $categoryId);
		}

		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where(
					'(a.title LIKE ' . $search
					.' OR a.alias LIKE ' . $search . ')'
				);
			}
		}

		// Filter on the language.
		if ($language = $this->getState('filter.language')) {
			$query->where('a.language = ' . $db->quote($language));
		}

		// Filter by featrued
		if ($language = $this->getState('filter.featured')) {
			$query->where('a.featured = 1');
		}

		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering', 'ordering');
		$orderDirn	= $this->state->get('list.direction', 'asc');
		$query->order($db->escape($orderCol . ' ' . $orderDirn));

		return $query;
	}

}
